#include <iostream>
#include <fstream>
#include "BoardImage.h"
#include "Display.h"
#include "Board.h"


Board::Board (void)
{
	Reset();
}

void Board::LoadImages(std::string filename)
{
	board.Load(			filename, sprite_board);
    nothing.Load(		filename, sprite_nothing);
    piece.Load(			filename, sprite_piece);
    selectedPiece.Load(	filename, sprite_selectedPiece);
}

void Board::SetDisplay(Display *displayIn)
{	
	if (displayIn)
		display = displayIn;
	else
		std::cerr << "NULL pointer passed to Board::SetDisplay" << std::endl;
}

void Board::DisplayBoard(void)
{
	if (!display)
	{
		std::cerr << "no display" << std::endl;
		return;
	}
		
  	for (int i = 0; i < 7; i ++)
	{
		for (int j = 0; j < 7; j++)
		{
			switch (boardState[i][j]) 
			{
				case position_nothing:	display->DrawGrid(i, j, nothing);
										break;
				case position_selectedPiece:	display->DrawGrid(i, j, selectedPiece);
										break;
				case position_board:	display->DrawGrid(i, j, board);
										break;
				case position_piece:	display->DrawGrid(i, j, piece);
										break;
				default:	std::cerr<<"Error in board state"<<std::endl;
			}
		}
	}	
}

void Board::Reset(void)
{
	std::ifstream input;
	input.open(PKGDATADIR "/marblesBoard.txt");
	if (!input)
	{
		std::cerr<<"can't open marblesBoard.txt"<<std::endl;
		for (int i = 0; i < 7; i ++)
		{
			for (int j = 0; j < 7; j++)
			{
				boardState[i][j] = position_piece;
			}
		}
		return;
	}
	
	//holds a character from the text file
	char c;
	//fill in the whole board with piece
	for (int i = 0; i < 7; i ++)
	{
		for (int j = 0; j < 7; j++)
		{
			input>>c;
			switch (c) 
			{
				case 'n':	boardState[i][j] = position_nothing;
							break;
				case 'p': 	boardState[i][j] = position_piece;
							break;
				case 's':   boardState[i][j] = position_selectedPiece;
							break;
				case 'b':	boardState[i][j] = position_board;
							break;
				default:	std::cerr<<"Error in text file"<<std::endl;
			}
		}
	}	
	
	input.close();
}

void Board::SquareClicked(int squareX, int squareY)
{
	rules.DoMove(*this, Coord(squareX, squareY));
}

Coord Board::GetSelectedPiece(void)
{
	for (int i = 0; i < 7; i ++)
	{
		for (int j = 0; j < 7; j++)
		{
			if (boardState[i][j] == position_selectedPiece)
				return Coord(i,j);	
		}
	}
	return Coord(-1,-1);
}
	

bool Board::IsAnyPieceSelected(void)
{
	Coord selected = GetSelectedPiece();
	if (selected.x == -1 ||selected.y == -1)
		return false;
	else return true;
}

position Board::GetSquare(Coord sqr)
{
	if (sqr.x > -1 && sqr.x < 7 && sqr.y > -1 && sqr.y < 7)
		return boardState[sqr.x][sqr.y];
	else
		return position_nothing;
}

void Board::SetSquare(Coord sqr, position pos)
{
	if (sqr.x > -1 && sqr.x < 7 && sqr.y > -1 && sqr.y < 7)
		boardState[sqr.x][sqr.y] = pos;
}
