#include "BoardImage.h"
#include <iostream>
#include "SDL_image.h"

void BoardImage::Load(std::string filename, sprite s)
{
	FreeSurface();
    SDL_Surface *tempSurface=IMG_Load(filename.c_str());
    if(!tempSurface)
    {
        std::cout<<"Error loading "<<filename<<": "<<IMG_GetError()<<std::endl;
        return;
    }
    
     surface = SDL_CreateRGBSurface(tempSurface->flags,
     								tempSurface->w/2, 
     								tempSurface->h/2,
     								tempSurface->format->BitsPerPixel, 
     								tempSurface->format->Rmask, 
     								tempSurface->format->Gmask, 
     								tempSurface->format->Bmask,
     								tempSurface->format->Amask);
	if(!surface)
    {
        std::cout<<"Error loading "<<filename<<": "<<SDL_GetError()<<std::endl;
        return;
    }

    //Copy the palette if it exists
    if (tempSurface->format->palette) 
    {
    	SDL_SetColors(surface, tempSurface->format->palette->colors, 0,
        	          tempSurface->format->palette->ncolors);
    }
    	
	// turn off the destination alpha so the copy works. 
	SDL_SetAlpha(surface,0,0);
    
    SDL_Rect rect;
	rect.w = surface->w;
	rect.h = surface->h;

	switch (s)
	{
		//Top right
		case sprite_nothing:	
						rect.x = surface->w;
						rect.y = 0;
						break;
		//Bottom right
		case sprite_board:
						rect.x = surface->w;
						rect.y = surface->h;
						break;
		//Top left on top of the bottom right
		case sprite_piece:
						rect.x = surface->w;
						rect.y = surface->h;
						if(SDL_BlitSurface(tempSurface, &rect, surface, NULL) < 0)
					    {
					        std::cout<<"BlitSurface error "<<SDL_GetError()<< std::endl;
					    }
					    rect.x = 0;
						rect.y = 0;
						break;
		//Bottom left on top of the bottom right
		case sprite_selectedPiece:
						rect.x = surface->w;
						rect.y = surface->h;
						if(SDL_BlitSurface(tempSurface, &rect, surface, NULL) < 0)
					    {
					        std::cout<<"BlitSurface error "<<SDL_GetError()<< std::endl;
					    }
					    rect.x = 0;
						rect.y = surface->h;
						break;
	}
	
    // Blit onto the surface 
    if(SDL_BlitSurface(tempSurface, &rect, surface, NULL) < 0)
    {
        std::cout<<"BlitSurface error "<<SDL_GetError()<< std::endl;
    }
    
/* FIXME: This makes it not work.  I don't know why, it seems like it
 * should be done.
 * 
    // set dest. alpha flags back to the source flags
	SDL_SetAlpha(	surface,
		(tempSurface->flags & SDL_SRCALPHA) | (tempSurface->flags & SDL_RLEACCEL),
		tempSurface->format->alpha);	
*/	

	SDL_FreeSurface(tempSurface);
}
