#include <string>
#include <iostream>
#include <fstream>
#include "Controller.h"
#include "MessageImage.h"
#include "Display.h"
#include "Board.h"
#include "Image.h"

Controller::Controller()
{
	board.SetDisplay(&display);	
}

void Controller::ChangeTileset(std::string filename)
{
	std::string board_file, menu_file, message_file;
	std::string window_size, center, board_size;

	std::string key, temp, value;
	
	std::ifstream input;
	input.open(filename.c_str());
	
	/* FIXME make this more flexible, so things like "200    x 300" don't mess
	 * it up 
	 */
	while(input.good())
	{
		input >> key;
		if (!input.good())
			break;
		
		if ('#' == key[0])
		{
			std::cout << "We got a comment" << std::endl;
			while ('\n' != input.get());
			continue;
		}
		
		input >> temp >> value;
		if (!input.good())
			break;
			
			
		std::cout << "We got: " << key << temp << value <<std::endl;
		
		if (key == "Board") 
			board_file = "/" + value;
		else if (key == "Menu")
			menu_file = "/" + value;
		else if (key == "Messages")
			message_file = "/" + value;
		else if (key == "WindowSize")
			window_size = value;
		else if (key == "BoardSize")
			board_size = value;
		else if (key == "Center")
			center = value;
		else
			std::cout<<"Ignoring "<< key << temp << value <<std::endl;
	}
	
	input.close();
	
	board.LoadImages(PKGDATADIR+board_file);
	menu.Load(PKGDATADIR + menu_file);
	win.Load(PKGDATADIR + message_file, message_win);
	lose.Load(PKGDATADIR + message_file, message_lose);

	// FIXME: make these use the actual sizes
	display.SetWindowSize(420, 470);
	display.SetBoardSize(420, 420);
	display.SetCenter(210, 260);

	display.DrawMenu(menu);
	board.DisplayBoard();
	display.UpdateScreen();
}

void Controller::GameLoop(void)
{
	SDL_Event event;
	while( SDL_WaitEvent( &event ) )
	{
		switch( event.type )
		{
	 		case (SDL_KEYDOWN): 		if(event.key.keysym.sym==SDLK_q)
		        							return;
		        						else if(event.key.keysym.sym==SDLK_r)
		        						{
		        							board.Reset();
		        							board.DisplayBoard();
											display.UpdateScreen();
		        						}
		        						break;
        	case (SDL_MOUSEBUTTONDOWN): if(event.button.button == SDL_BUTTON_LEFT)
        								{
        									int squareX, squareY;
        									display.ConvertPixelToSquare(event.button.x, event.button.y,
        														 squareX, squareY);
        									std::cout<<"Pressed: x= "<<event.button.x
        													<<", y= "<<event.button.y
        											 <<" Square: x= "<<squareX
        											 		<<", y= "<<squareY
        													<<std::endl;
        									if (squareX > -1)
        									{
		    									board.SquareClicked(squareX, squareY);
		    									board.DisplayBoard();
		    									if (board.IsGameOver())
												{
													std::cout<<"Game Over"<<std::endl;
													if (board.IsGameWon())
													{
														display.DrawCentered(win);
														std::cout<<"You Win"<<std::endl;
													}
													else
													{
														display.DrawCentered(lose);
														std::cout<<"You Lose"<<std::endl;
													}
												}
												else
													std::cout<<"Game Not Over"<<std::endl;
												display.UpdateScreen();
        									}
        								}
        								break;
	 		case (SDL_QUIT):    		return;							 							
	    }
	}

	
}

