#include "Display.h"
#include "config.h"	// FIXME: put in common.h wrapper for HAVE_CONFIG
#include <iostream>

Display::~Display(void)
{
	Shutdown();
}


void Display::Shutdown(void)
{
	SDL_Quit();
}


void Display::Draw(int x, int y, SDL_Surface *image )
{
	SDL_Rect rect;
	rect.x = x;
	rect.y = y;
	
	/*
     * Palettized screen modes will have a default palette (a standard
     * 8*8*4 colour cube), but if the image is palettized as well we can
     * use that palette for a nicer colour matching
     */
    if (image->format->palette && screen->format->palette) {
    SDL_SetColors(screen, image->format->palette->colors, 0,
                  image->format->palette->ncolors);
    }

    /* Blit onto the screen surface */
    if(SDL_BlitSurface(image, NULL, screen, &rect) < 0)
    {
        std::cout<<"BlitSurface error "<<SDL_GetError()<< std::endl;
    }
}


void Display::UpdateScreen(void)
{
	SDL_UpdateRect(screen, 0, 0, screen->w, screen->h);
}


void Display::DrawGrid(int row, int col, Image &img)
{
	SDL_Surface *image = img.GetSurface();
	
	//get the origin (top left corner)
	int originX = centerX-boardWidth/2;
	int originY = centerY-boardHeight/2;
	
	//get the height of a single square
	int squareHeight = boardHeight/NumSquares;
	int squareWidth = boardWidth/NumSquares;
	
	//get top left corner of the desired square
	int x = originX+row*squareWidth;
	int y = originY+col*squareHeight;
	
//	Draw(x-image->w/2, y-image->w/2, image);
	Draw(x, y, image);
}


void Display::DrawCentered(Image &img)
{
	SDL_Surface *image = img.GetSurface();
	
	Draw(centerX-image->w/2, centerY-image->h/2, image);
}
void Display::DrawMenu(Image &img)
{	
	SDL_Surface *image = img.GetSurface();
	
	Draw(0,0, image);
}


void Display::SetWindowSize(int x, int y)
{
	/* Initialize the SDL library */
    if( SDL_Init(SDL_INIT_VIDEO) < 0 ) {
        //fprintf(stderr,"Couldn't initialize SDL: %s\n", SDL_GetError());
        exit(1);
    }
 
    /*
     * Initialize the display in a 640x480 8-bit palettized mode,
     * requesting a software surface
     */
    screen = SDL_SetVideoMode(x, y, 16, SDL_SWSURFACE);
    if ( screen == NULL ) {
        //fprintf(stderr, "Couldn't set 640x480x16 video mode: %s\n",SDL_GetError());
        exit(1);
    }
    SDL_WM_SetCaption(PACKAGE_NAME, NULL);	// FIXME: get an icon
}

void Display::SetBoardSize(int x, int y)
{
	boardWidth = x;
	boardHeight = y;
}

void Display::SetCenter(int x, int y)
{
	centerX = x;
	centerY = y;
}

void Display::ConvertPixelToSquare(int x, int y, int &xOut, int &yOut)
{
	//coordinates of the edges of the board
	int xEdge = centerX-boardWidth/2;
	int yEdge = centerY-boardHeight/2;
	
	//"move" the board to the upper left corner
	x -= xEdge;
	y -= yEdge;
	
	if (x < 0 || y < 0 || x >= boardWidth || y >= boardHeight)
	{
		xOut = -1;
		yOut = -1;
		return;
	} 
	
	//convert
	xOut = x/(boardWidth/NumSquares);
	yOut = y/(boardHeight/NumSquares);
}
