#include "Rulebook.h"
#include <stdlib.h>


void Rulebook::DoMove(Board &brd, Coord sqr)
{
	if (brd.GetSquare(sqr) == position_piece)
	{
		if (brd.IsAnyPieceSelected())
		{
			Coord selected = brd.GetSelectedPiece();
			brd.SetSquare(selected, position_piece);
		}
		brd.SetSquare(sqr, position_selectedPiece);
		
	}
	else  
	{
		Coord selected = brd.GetSelectedPiece();
		Coord middleSquare = Coord ((sqr.x+selected.x)/2, (sqr.y+selected.y)/2);
		if (IsLegalMove(brd, selected, sqr))
		{
			brd.SetSquare(selected, position_board);
			brd.SetSquare(sqr, position_selectedPiece);
			brd.SetSquare(middleSquare, position_board);
		}
	}	
}

bool Rulebook::IsLegalMove(Board &brd, Coord source, Coord destination)
{
	//checks if the move is legal
	if ((destination.y == source.y && abs(destination.x-source.x) == 2) || //horizontal row
		(destination.x == source.x && abs(destination.y-source.y) == 2))   //vertical row
	{
		Coord middleSquare = Coord ((destination.x+source.x)/2, (destination.y+source.y)/2);
		if ((brd.GetSquare(middleSquare) == position_piece || brd.GetSquare(middleSquare) == position_selectedPiece) &&
		    brd.GetSquare(destination) == position_board &&
		    (brd.GetSquare(source) == position_selectedPiece || brd.GetSquare(source) == position_piece))
			return true;
	}
	return false;
}

bool Rulebook::IsGameOver(Board &brd)
{
	for (int i=0; i<7; i++)
	{
		for (int j=0; j<7; j++)
		{
			if (IsLegalMove(brd, Coord(i,j), Coord(i, j-2)))
				return false;
			if (IsLegalMove(brd, Coord(i,j), Coord(i, j+2)))
				return false;
			if (IsLegalMove(brd, Coord(i,j), Coord(i-2, j)))
				return false;
			if (IsLegalMove(brd, Coord(i,j), Coord(i+2, j)))
				return false;
		}
	}
	return true;
}

bool Rulebook::IsGameWon(Board &brd)
{
	int pieceCount = 0;
	for (int i=0; i<7; i++)
	{
		for (int j=0; j<7; j++)
		{
			if ( brd.GetSquare(Coord(i,j)) == position_piece || 
				 brd.GetSquare(Coord(i,j)) == position_selectedPiece)	
				 pieceCount++;
		}
	}
	if (pieceCount == 1 && ( brd.GetSquare(Coord(3,3)) == position_piece || 
				 			 brd.GetSquare(Coord(3,3)) == position_selectedPiece))
		return true;
	else
		return false;
}
